

dk-template - debugging django templates.
====================================================

Parse a django template and find all template variables that are used.
Output the template variables in a format that can be included in the
template to verify the values of all context variables.

.. image:: https://travis-ci.org/datakortet/dk-template.svg?branch=master
    :target: https://travis-ci.org/datakortet/dk-template

.. image:: https://gitlab.com/norsktest/dk-template/badges/master/pipeline.svg
   :target: https://gitlab.com/norsktest/dk-template/commits/master
   :alt: pipeline status

.. image:: https://img.shields.io/badge/docs-darkgreen.svg
   :target: https://norsktest.gitlab.io/dk-template
   :alt: documentation

.. image:: https://codecov.io/gl/norsktest/dk-template/branch/master/graph/badge.svg?token=6E4JXSMACJ
  :target: https://codecov.io/gl/norsktest/dk-template
